import { animate, keyframes, query, stagger, style, transition, trigger } from '@angular/animations';
import { isPlatformBrowser, CommonModule } from '@angular/common';
import { Inject, Injectable, Optional, PLATFORM_ID, ChangeDetectionStrategy, Component, ViewEncapsulation, ChangeDetectorRef, HostBinding, Input, NgZone, ViewChild, Renderer2, Host, ApplicationRef, ComponentFactoryResolver, Injector, HostListener, NgModule, SkipSelf, defineInjectable, inject, INJECTOR } from '@angular/core';
import { BehaviorSubject, of } from 'rxjs';
import { map, share } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const hasV8BreakIterator = (typeof Intl !== 'undefined' && ((/** @type {?} */ (Intl))).v8BreakIterator);
class Platform {
    /**
     * @param {?=} _platformId
     */
    constructor(_platformId) {
        this._platformId = _platformId;
    }
    // Browser check.
    /**
     * @return {?}
     */
    get isBrowser() {
        return this._platformId
            ? isPlatformBrowser(this._platformId)
            : typeof document === 'object' && !!document;
    }
    // Rendering engines.
    /**
     * @return {?}
     */
    get isTrident() {
        return this.isBrowser && /(msie|trident)/i.test(navigator.userAgent);
    }
    /**
     * @return {?}
     */
    get isBlink() {
        return this.isBrowser && (!!(((/** @type {?} */ (window))).chrome || hasV8BreakIterator) &&
            typeof CSS !== 'undefined' && !this.isEdge && !this.isTrident);
    }
    /**
     * @return {?}
     */
    get isWebkit() {
        return this.isBrowser && /AppleWebKit/i.test(navigator.userAgent)
            && !this.isBlink && !this.isEdge && !this.isTrident;
    }
    // Browsers.
    /**
     * @return {?}
     */
    get isChrome() {
        return this.isBrowser && /Google Inc./.test(navigator.vendor);
    }
    /**
     * @return {?}
     */
    get isEdge() {
        return this.isBrowser && /(edge)/i.test(navigator.userAgent);
    }
    /**
     * @return {?}
     */
    get isFirefox() {
        return this.isBrowser && /(firefox|minefield)/i.test(navigator.userAgent);
    }
    /**
     * @return {?}
     */
    get isSafari() {
        return this.isBrowser && /safari/i.test(navigator.userAgent) && this.isWebkit;
    }
    // Platforms.
    /**
     * @return {?}
     */
    get isIos() {
        return this.isBrowser && /iPad|iPhone|iPod/.test(navigator.userAgent) && !('MSStream' in window);
    }
    /**
     * @return {?}
     */
    get isAndroid() {
        return this.isBrowser && /android/i.test(navigator.userAgent) && !this.isTrident;
    }
}
Platform.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
Platform.ctorParameters = () => [
    { type: Object, decorators: [{ type: Optional }, { type: Inject, args: [PLATFORM_ID,] }] }
];
/** @nocollapse */ Platform.ngInjectableDef = defineInjectable({ factory: function Platform_Factory() { return new Platform(inject(PLATFORM_ID, 8)); }, token: Platform, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Language {
    constructor() {
        this.getLanguages = () => {
            if (typeof navigator !== 'object') {
                return null;
            }
            /** @type {?} */
            let t = 'anguage';
            /** @type {?} */
            let n = navigator;
            /** @type {?} */
            let f = n['l' + t + 's'];
            /** @type {?} */
            const data = f && f.length ? f : (t = n['l' + t] ||
                n['browserL' + t] ||
                n['userL' + t]) ? [t] : t;
            return typeof data === 'string'
                ? data
                : data.join(';');
        };
    }
    /**
     * @return {?}
     */
    get all() {
        // Get the languages.
        /** @type {?} */
        const data = this.getLanguages();
        // Parse all languages by using a regex.
        /** @type {?} */
        const strings = (data || '')
            .match(/((([a-zA-Z]+(-[a-zA-Z0-9]+){0,2})|\*)(;q=[0-1](\.[0-9]+)?)?)*/g);
        // Get the content by parsing the strings.
        /** @type {?} */
        const content = strings.map(item => {
            if (!item) {
                return null;
            }
            /** @type {?} */
            const bits = item.split(';');
            /** @type {?} */
            const ietf = bits[0].split('-');
            /** @type {?} */
            const hasScript = ietf.length === 3;
            return {
                code: ietf[0],
                script: hasScript ? ietf[1] : null,
                region: hasScript ? ietf[2] : ietf[1],
                quality: bits[1] ? parseFloat(bits[1].split('=')[1]) : 1.0
            };
        });
        // Filter out all the empty items
        // and sort them by the quality.
        return content
            .filter(item => !!item)
            .sort((a, b) => b.quality - a.quality);
    }
}
Language.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */ Language.ngInjectableDef = defineInjectable({ factory: function Language_Factory() { return new Language(); }, token: Language, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbDashboard {
    /**
     * @param {?} _renderer
     */
    constructor(_renderer) {
        this._renderer = _renderer;
        // Inputs.
        this.backgroundColor = '#d5dae6';
        this.maxWidth = '1200px';
        this.padding = '20px';
        // State.
        this.sidebarVisible$ = new BehaviorSubject(true);
    }
    /**
     * @return {?}
     */
    get visibility() {
        return this.sidebarVisible$.asObservable();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // Set the HTML class to prevent scrolling.
        return this.setHtmlClass();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // Remove the HTML class.
        return this.setHtmlClass(true);
    }
    /**
     * @return {?}
     */
    toggleSidebarVisibility() {
        // Get the previous value.
        /** @type {?} */
        const previousValue = this.sidebarVisible$.getValue();
        // Invert the value and set the visibility.
        this.setSidebarVisibility(!previousValue);
    }
    /**
     * @param {?} newValue
     * @return {?}
     */
    setSidebarVisibility(newValue) {
        this.sidebarVisible$.next(newValue);
    }
    /**
     * @private
     * @param {?=} shouldRemove
     * @return {?}
     */
    setHtmlClass(shouldRemove = false) {
        // Check if the document element is available.
        if (!document || !document.documentElement) {
            return;
        }
        // Define the class name.
        /** @type {?} */
        const className = 'bb-dashboard-html';
        // Add or remove the class.
        return shouldRemove
            ? this._renderer.removeClass(document.documentElement, className)
            : this._renderer.addClass(document.documentElement, className);
    }
}
BbDashboard.decorators = [
    { type: Component, args: [{
                selector: 'bb-dashboard',
                template: "<!--\r\n    The outlet for where the sidebar\r\n    will be placed (if provided).\r\n-->\r\n<ng-content select=\"bb-dashboard-sidebar\">\r\n</ng-content>\r\n\r\n<!--\r\n    The section containing the header\r\n    and the main content.\r\n-->\r\n<section class=\"bb-dashboard-section\">\r\n    <!--\r\n        The outlet for where the header\r\n        will be placed (if provided).\r\n    -->\r\n    <ng-content select=\"bb-dashboard-header\">\r\n    </ng-content>\r\n\r\n    <!--\r\n        The outlet of the content that\r\n        will be provided by the router.\r\n    -->\r\n    <main [style.background-color]=\"backgroundColor\"\r\n          [style.padding]=\"padding\"\r\n          class=\"bb-dashboard-scroll\">\r\n        <div [style.max-width]=\"maxWidth\"\r\n             class=\"bb-dashboard-container\">\r\n            <ng-content></ng-content>\r\n        </div>\r\n    </main>\r\n</section>\r\n\r\n<!--\r\n    The backdrop that will be visible when\r\n    the sidebar is opened (only on mobile).\r\n-->\r\n<div [class.bb-dashboard-backdrop--visible]=\"!(visibility | async)\"\r\n     (click)=\"toggleSidebarVisibility()\"\r\n     class=\"bb-dashboard-backdrop\">\r\n</div>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'class': 'bb-dashboard'
                },
                styles: [".bb-dashboard{height:100vh;display:-ms-flexbox;display:flex;overflow:hidden;position:relative}.bb-dashboard-section{-ms-flex:1;flex:1;height:100vh;display:-ms-flexbox;display:flex;overflow-x:hidden;-ms-flex-direction:column;flex-direction:column}.bb-dashboard-scroll{-ms-flex:1;flex:1;overflow-x:hidden;overflow-y:scroll;-webkit-overflow-scrolling:touch}.bb-dashboard-container{width:100%;margin:0 auto}.bb-dashboard-backdrop{top:0;left:0;right:0;bottom:0;opacity:0;z-index:5;position:absolute;will-change:opacity;pointer-events:none;background-color:rgba(0,0,0,.5);transition:opacity .2s cubic-bezier(0,0,.2,1)}.bb-dashboard-backdrop--visible{opacity:1;cursor:pointer;pointer-events:all}@media only screen and (min-width:768px){.bb-dashboard-backdrop{display:none}}.bb-dashboard-html{height:100%;overflow:hidden}"]
            }] }
];
/** @nocollapse */
BbDashboard.ctorParameters = () => [
    { type: Renderer2 }
];
BbDashboard.propDecorators = {
    backgroundColor: [{ type: Input }],
    maxWidth: [{ type: Input }],
    padding: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbDashboardHeader {
    /**
     * @param {?} _parent
     */
    constructor(_parent) {
        this._parent = _parent;
    }
    /**
     * @return {?}
     */
    get isSidebarVisible() {
        return this._parent
            ? this._parent.visibility
            : of(false);
    }
    /**
     * @return {?}
     */
    onToggleSidebarClicked() {
        // If the parent exists toggle the sidebar visibility.
        if (!this._parent) {
            return;
        }
        this._parent.toggleSidebarVisibility();
    }
}
BbDashboardHeader.decorators = [
    { type: Component, args: [{
                selector: 'bb-dashboard-header',
                template: "<!--\r\n    The button that toggles the sidebar.\r\n-->\r\n<button (click)=\"onToggleSidebarClicked()\"\r\n        [class.bb-dashboard-header-button--reversed]=\"isSidebarVisible | async\"\r\n        class=\"bb-dashboard-header-button\"\r\n        type=\"button\"\r\n        tabindex=\"0\"\r\n        role=\"switch\">\r\n    <svg xmlns=\"http://www.w3.org/2000/svg\"\r\n         viewBox=\"0 0 157 109\"\r\n         width=\"17\"\r\n         height=\"12\"\r\n         role=\"img\">\r\n        <title>\r\n            Toggle\r\n        </title>\r\n        <path fill=\"#fff\"\r\n              d=\"M82 42V11.2L30 54.5l52 43.3V67h75V42zM9.5 109h-2c-4.1 0-7.5-3.4-7.5-7.5v-94C0 3.4 3.4 0 7.5 0h2C13.6 0 17 3.4 17 7.5v94c0 4.1-3.4 7.5-7.5 7.5z\">\r\n        </path>\r\n    </svg>\r\n</button>\r\n\r\n<!--\r\n    The extra items of the header.\r\n-->\r\n<div class=\"bb-dashboard-header-items\">\r\n    <ng-content></ng-content>\r\n</div>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'class': 'bb-dashboard-header'
                },
                styles: [".bb-dashboard-header{z-index:1;width:100%;color:#fff;height:50px;display:-ms-flexbox;display:flex;padding:0 8px;min-height:50px;-ms-flex-align:center;align-items:center;background-color:#3f51b5;border-bottom:1px solid #303f9f}.bb-dashboard-header-button{width:68px;height:34px;border-radius:4px;-ms-flex-align:center;align-items:center;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-pack:center;justify-content:center;border:1px solid #283593;background-color:transparent}.bb-dashboard-header-button>svg{height:100%;-webkit-transform:none;-ms-transform:none;transform:none;transition:transform .2s cubic-bezier(0,0,.2,1);transition:transform .2s cubic-bezier(0,0,.2,1),-webkit-transform .2s cubic-bezier(0,0,.2,1)}.bb-dashboard-header-button--reversed>svg{-webkit-transform:rotateY(180deg);transform:rotateY(180deg)}.bb-dashboard-header-button:hover{background-color:rgba(0,0,0,.04)}.bb-dashboard-header-button:active{background-color:rgba(0,0,0,.08)}.bb-dashboard-header-items{display:-ms-flexbox;display:flex;margin-left:auto;-ms-flex-align:center;align-items:center}.bb-dashboard-header-items>:not(:first-child){margin-left:8px}@media only screen and (min-width:768px){.bb-dashboard-header-button>svg{-webkit-transform:rotateY(180deg);transform:rotateY(180deg)}.bb-dashboard-header-button--reversed>svg{-webkit-transform:none;-ms-transform:none;transform:none}}"]
            }] }
];
/** @nocollapse */
BbDashboardHeader.ctorParameters = () => [
    { type: BbDashboard, decorators: [{ type: Optional }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbDashboardSidebar {
    /**
     * @param {?} _platform
     * @param {?} _parent
     */
    constructor(_platform, _parent) {
        this._platform = _platform;
        this._parent = _parent;
        // Bindings.
        this.visible = true;
        // State.
        this._state$ = new BehaviorSubject([]);
        // Token.
        this._localStorageToken = 'bb-dashboard-sidebar-state';
        this.saveCache = (data) => {
            // Get the local storage.
            /** @type {?} */
            const localStorage = this.getLocalStorage();
            // Check if the local storage exists.
            if (!localStorage) {
                return;
            }
            // Set the cache in the local storage.
            try {
                localStorage.setItem(this._localStorageToken, JSON.stringify(data));
            }
            catch (error) {
                console.log('Error setting local storage data.');
            }
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // Retrieve and set the cache.
        this.setCache();
        // Get the visibility observable from the parent
        // if the parent exists.
        /** @type {?} */
        const observable$ = this._parent
            ? this._parent.visibility
            : of(false);
        // Subscribe to get the state changes.
        this._subscription = observable$
            .subscribe(value => this.visible = value);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // Unsubscribe to prevent memory leaks.
        this._subscription && this._subscription.unsubscribe();
    }
    /**
     * @param {?} id
     * @return {?}
     */
    registerGroup(id) {
        // Get the current groups.
        /** @type {?} */
        const current = this._state$.getValue();
        // Check if the id is already inside the groups.
        if (current.findIndex(item => item.id === id) > -1) {
            throw new Error('Group id was already defined; can only have distinct id\'s.');
        }
        // Check if the item is in the cache
        // and create a new entry.
        /** @type {?} */
        const cacheItem = this._cache.find(item => item.id === id);
        /** @type {?} */
        const newEntry = {
            id: id,
            state: cacheItem ? cacheItem.state : 'opened'
        };
        // Push the new groups array.
        this._state$.next([...current, newEntry]);
        // Return the slice of the state that the group needs.
        return this._state$.pipe(map(state => state.find(item => item.id === id)), map(group => group.state));
    }
    /**
     * @param {?} id
     * @return {?}
     */
    unregisterGroup(id) {
        // Get the old groups.
        /** @type {?} */
        const oldValue = this._state$.getValue();
        // Calculate the new groups.
        /** @type {?} */
        const newValue = oldValue.filter(item => item.id !== id);
        // Push the new groups array.
        this._state$.next(newValue);
    }
    /**
     * @param {?} id
     * @param {?} newState
     * @return {?}
     */
    toggleGroup(id, newState) {
        // Get the old groups.
        /** @type {?} */
        const oldValue = this._state$.getValue();
        // Create the new groups.
        /** @type {?} */
        const newValue = oldValue.map(item => {
            return item.id !== id
                ? item
                : { id: id, state: newState };
        });
        // Push the new groups array.
        this._state$.next(newValue);
        // Save in the cache.
        this.saveCache(newValue);
    }
    /**
     * @return {?}
     */
    close() {
        // Set the sidebar visibility to true, this means
        // that on mobile the sidebar will be closed.
        this._parent.setSidebarVisibility(true);
    }
    /**
     * @private
     * @return {?}
     */
    getLocalStorage() {
        // Check if the current platform is a browser.
        if (!this._platform.isBrowser) {
            return null;
        }
        // Check if the window and local storage exist.
        return window && window.localStorage
            ? localStorage
            : null;
    }
    /**
     * @private
     * @return {?}
     */
    setCache() {
        // Get the local storage.
        /** @type {?} */
        const localStorage = this.getLocalStorage();
        // Check if the local storage exists.
        if (!localStorage) {
            return;
        }
        // Retrieve the raw data from the storage.
        /** @type {?} */
        const rawData = localStorage.getItem(this._localStorageToken);
        // Try to parse the data.
        /** @type {?} */
        let parsedData = null;
        // Only parse the data when it is not null.
        if (rawData !== null) {
            try {
                parsedData = JSON.parse(rawData);
            }
            catch (error) {
                console.log('Error parsing local storage data.');
            }
        }
        // Set the cache to the parsed data.
        this._cache = parsedData || [];
    }
}
BbDashboardSidebar.decorators = [
    { type: Component, args: [{
                selector: 'bb-dashboard-sidebar',
                template: "<!--\r\n    The header of the sidebar.\r\n-->\r\n<header class=\"bb-dashboard-sidebar-header\">\r\n    <ng-content>\r\n    </ng-content>\r\n</header>\r\n\r\n<!--\r\n    The scroll area that contains the\r\n    groups in the navigation.\r\n-->\r\n<div class=\"bb-dashboard-sidebar-scroll\">\r\n    <ng-content select=\"bb-dashboard-sidebar-group\"></ng-content>\r\n</div>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'class': 'bb-dashboard-sidebar',
                    'role': 'navigation'
                },
                styles: [".bb-dashboard-sidebar{top:0;bottom:0;z-index:10;left:-256px;width:256px;height:100vh;display:block;position:fixed;min-width:256px;will-change:transform;-webkit-transform:translateX(256px);-ms-transform:translateX(256px);transform:translateX(256px);border-right:1px solid rgba(0,0,0,.4);transition:transform 250ms cubic-bezier(0,0,.2,1);transition:transform 250ms cubic-bezier(0,0,.2,1),-webkit-transform 250ms cubic-bezier(0,0,.2,1);background:linear-gradient(to bottom,#fff,#f2f2f2) #fff}.bb-dashboard-sidebar.visible{-webkit-transform:none;-ms-transform:none;transform:none}.bb-dashboard-sidebar-header{height:120px;display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center;border-bottom:1px solid #d8d8d8;background-color:rgba(255,255,255,.5)}.bb-dashboard-sidebar-scroll{overflow:auto;height:calc(100vh - 120px)}@media only screen and (min-width:768px){.bb-dashboard-sidebar{left:0;z-index:auto;-webkit-transform:none;-ms-transform:none;transform:none;position:relative;margin-left:-256px;transition:margin-left 250ms cubic-bezier(0,0,.2,1)}.bb-dashboard-sidebar.visible{margin-left:0}}"]
            }] }
];
/** @nocollapse */
BbDashboardSidebar.ctorParameters = () => [
    { type: Platform },
    { type: BbDashboard, decorators: [{ type: Optional }, { type: Host }] }
];
BbDashboardSidebar.propDecorators = {
    visible: [{ type: HostBinding, args: ['class.visible',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbDashboardSidebarGroup {
    /**
     * @param {?} _parent
     */
    constructor(_parent) {
        this._parent = _parent;
        // Inputs.
        this.id = null;
        this.icon = null;
        this.title = null;
        // State.
        this.state = 'opened';
    }
    // Host bindings.
    /**
     * @return {?}
     */
    get isExpanded() {
        return this.state === 'opened';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // Check if the id and title have been supplied.
        if (!this.id || !this.title) {
            throw new Error('Id and title are required.');
        }
        // Register the group at the parent and
        // retrieve the slice of the state.
        /** @type {?} */
        const observable$ = this._parent
            ? this._parent.registerGroup(this.id)
            : of('opened');
        // Subscribe to the state.
        this._subscription = observable$
            .subscribe(state => this.state = state);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // Unsubscribe to prevent memory leaks.
        this._subscription && this._subscription.unsubscribe();
        // Unregister the group at the parent.
        this._parent && this._parent.unregisterGroup(this.id);
    }
    /**
     * @return {?}
     */
    onClick() {
        // Change the state.
        /** @type {?} */
        const nextState = this.state === 'opened' ? 'closed' : 'opened';
        // Set the state of the sidebar.
        this._parent && this._parent.toggleGroup(this.id, nextState);
    }
    /**
     * @return {?}
     */
    onItemClicked() {
        // Close the sidebar on the parent.
        this._parent && this._parent.close();
    }
}
BbDashboardSidebarGroup.decorators = [
    { type: Component, args: [{
                selector: 'bb-dashboard-sidebar-group',
                template: "<!--\r\n    The wrapper that contains the title and icon.\r\n-->\r\n<button (click)=\"onClick()\"\r\n        class=\"bb-dashboard-sidebar-group-title\"\r\n        type=\"button\"\r\n        role=\"switch\">\r\n    <i *ngIf=\"icon\"\r\n       class=\"material-icons bb-dashboard-sidebar-group-icon\">\r\n        {{ icon }}\r\n    </i>\r\n    <span *ngIf=\"title\"\r\n          class=\"bb-dashboard-sidebar-group-text\">\r\n        {{ title }}\r\n    </span>\r\n    <span class=\"bb-dashboard-sidebar-group-toggle\">\r\n        <svg xmlns=\"http://www.w3.org/2000/svg\"\r\n             viewBox=\"0 0 157 109\"\r\n             width=\"16\"\r\n             height=\"16\"\r\n             role=\"img\">\r\n            <title>\r\n                Toggle\r\n            </title>\r\n            <path\r\n                d=\"M82 42V11.2L30 54.5l52 43.3V67h75V42zM9.5 109h-2c-4.1 0-7.5-3.4-7.5-7.5v-94C0 3.4 3.4 0 7.5 0h2C13.6 0 17 3.4 17 7.5v94c0 4.1-3.4 7.5-7.5 7.5z\">\r\n            </path>\r\n        </svg>\r\n    </span>\r\n</button>\r\n\r\n<!--\r\n    The sidebar items that contain the\r\n    links to navigate to other pages.\r\n-->\r\n<ng-content select=\"[bb-dashboard-sidebar-item]\">\r\n</ng-content>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'class': 'bb-dashboard-sidebar-group',
                    'role': 'group'
                },
                styles: [".bb-dashboard-sidebar-group{color:#000;display:block;overflow:hidden;border-bottom:1px solid rgba(0,0,0,.1);transition:background-color .2s cubic-bezier(0,0,.2,1),padding-bottom .2s cubic-bezier(0,0,.2,1)}.bb-dashboard-sidebar-group.expanded{padding-bottom:20px;background-color:rgba(0,0,0,.04)}.bb-dashboard-sidebar-group.expanded .bb-dashboard-sidebar-group-title{color:#000}.bb-dashboard-sidebar-group.expanded .bb-dashboard-sidebar-item{opacity:1;height:32px;line-height:32px;padding:6px 16px 6px 54px}.bb-dashboard-sidebar-group.expanded .bb-dashboard-sidebar-group-toggle>svg{-webkit-transform:rotate(90deg);-ms-transform:rotate(90deg);transform:rotate(90deg)}.bb-dashboard-sidebar-group-title{margin:0;width:100%;border:none;display:-ms-flexbox;display:flex;cursor:pointer;text-align:left;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-ms-flex-align:center;align-items:center;padding:17px 15px;color:rgba(0,0,0,.8);background-color:transparent;transition:color .2s cubic-bezier(0,0,.2,1)}.bb-dashboard-sidebar-group-title:focus>.bb-dashboard-sidebar-group-toggle,.bb-dashboard-sidebar-group-title:hover>.bb-dashboard-sidebar-group-toggle{opacity:1}.bb-dashboard-sidebar-group-title:active>.bb-dashboard-sidebar-group-toggle{background-color:rgba(0,0,0,.08)}.bb-dashboard-sidebar-group-icon{margin-right:15px;color:rgba(0,0,0,.25)}.bb-dashboard-sidebar-group-text{width:100%;display:block;font-size:14px;max-width:100%;overflow:hidden;font-weight:500;line-height:15px;white-space:nowrap;text-overflow:ellipsis;text-transform:uppercase}.bb-dashboard-sidebar-group-toggle{opacity:0;width:30px;height:30px;display:-ms-flexbox;display:flex;min-width:30px;min-height:30px;border-radius:50%;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center;transition:opacity .2s cubic-bezier(0,0,.2,1),background-color .2s cubic-bezier(0,0,.2,1)}.bb-dashboard-sidebar-group-toggle>svg{width:16px;height:16px;fill:rgba(0,0,0,.25);-webkit-transform:rotate(90deg) rotateY(180deg);transform:rotate(90deg) rotateY(180deg);transition:transform .2s cubic-bezier(0,0,.2,1);transition:transform .2s cubic-bezier(0,0,.2,1),-webkit-transform .2s cubic-bezier(0,0,.2,1)}"]
            }] }
];
/** @nocollapse */
BbDashboardSidebarGroup.ctorParameters = () => [
    { type: BbDashboardSidebar, decorators: [{ type: Optional }, { type: Host }] }
];
BbDashboardSidebarGroup.propDecorators = {
    isExpanded: [{ type: HostBinding, args: ['class.expanded',] }],
    id: [{ type: Input }],
    icon: [{ type: Input }],
    title: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbDashboardSidebarItem {
    /**
     * @param {?} _parent
     */
    constructor(_parent) {
        this._parent = _parent;
        // Inputs.
        this.tabIndex = 0;
    }
    /**
     * @return {?}
     */
    onClick() {
        // Trigger the parent on item clicked call
        // so that the sidebar can be closed.
        this._parent && this._parent.onItemClicked();
    }
    /**
     * @return {?}
     */
    get attributeTabIndex() {
        // Make the items tabindex -1 so it can't
        // be tabbed to when the parent is not expanded.
        if (!this._parent.isExpanded) {
            return -1;
        }
        // Else return the specified tabindex.
        return this.tabIndex;
    }
}
BbDashboardSidebarItem.decorators = [
    { type: Component, args: [{
                selector: '[bb-dashboard-sidebar-item]',
                template: "<!--\r\n    The content between the tags will\r\n    be reflected here.\r\n-->\r\n<span class=\"bb-dashboard-sidebar-item-content\">\r\n    <ng-content>\r\n    </ng-content>\r\n</span>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'class': 'bb-dashboard-sidebar-item',
                    '[attr.tabindex]': 'attributeTabIndex'
                },
                styles: [".bb-dashboard-sidebar-item{height:0;opacity:0;padding:0;display:-ms-flexbox;display:flex;line-height:0;cursor:pointer;font-size:14px;font-weight:500;margin-right:20px;-ms-flex-align:center;align-items:center;text-decoration:none;will-change:opacity,height;border-top-right-radius:16px;border-bottom-right-radius:16px;color:rgba(0,0,0,.85)!important;transition:height .2s cubic-bezier(0,0,.2,1),opacity .2s cubic-bezier(0,0,.2,1) 50ms,color .2s cubic-bezier(0,0,.2,1),background-color .2s cubic-bezier(0,0,.2,1)}.bb-dashboard-sidebar-item:focus,.bb-dashboard-sidebar-item:hover{background-color:rgba(0,0,0,.05)}.bb-dashboard-sidebar-item:active{background-color:rgba(0,0,0,.1)}.bb-dashboard-sidebar-item.active,.bb-dashboard-sidebar-item.active:active,.bb-dashboard-sidebar-item.active:focus,.bb-dashboard-sidebar-item.active:hover{color:#000;background-color:rgba(0,0,0,.15)}.bb-dashboard-sidebar-item-content{overflow:hidden;max-width:100%;white-space:nowrap;text-overflow:ellipsis}"]
            }] }
];
/** @nocollapse */
BbDashboardSidebarItem.ctorParameters = () => [
    { type: BbDashboardSidebarGroup, decorators: [{ type: Optional }] }
];
BbDashboardSidebarItem.propDecorators = {
    tabIndex: [{ type: Input }],
    onClick: [{ type: HostListener, args: ['click',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const DECLARATIONS_EXPORTS = [
    BbDashboard,
    BbDashboardHeader,
    BbDashboardSidebar,
    BbDashboardSidebarGroup,
    BbDashboardSidebarItem
];
class BbDashboardModule {
}
BbDashboardModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [...DECLARATIONS_EXPORTS],
                exports: [...DECLARATIONS_EXPORTS]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const BbNotificationType = {
    Success: 'success',
    Error: 'error',
    Warning: 'warning',
    Info: 'info',
    Custom: 'custom',
};
class BbNotificationsConfig {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const timing = '500ms';
/** @type {?} */
const timingFunction = `${timing} cubic-bezier(0, 0, .2, 1)`;
/** @type {?} */
const notificationAnimation = trigger('notificationListAnimation', [
    transition('* => *', [
        query(':enter', stagger(timing, [
            animate(timingFunction, keyframes([
                style({ height: 0, opacity: 0, transform: 'translateX(50%)', offset: 0 }),
                style({ height: '*', opacity: 0, transform: 'translateX(50%)', offset: 0.75 }),
                style({ height: '*', opacity: 1, transform: 'translateX(0)', offset: 1.0 })
            ]))
        ]), { optional: true }),
        query(':leave', stagger(timing, [
            animate(timingFunction, keyframes([
                style({ height: '*', opacity: 1, transform: 'translateX(0)', offset: 0 }),
                style({ height: '*', opacity: 0, transform: 'translateX(50%)', offset: 0.9 }),
                style({ height: 0, opacity: 0, transform: 'translateX(50%)', offset: 1.0 })
            ]))
        ]), { optional: true })
    ])
]);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbNotificationsList {
    constructor() {
        // Track by function.
        this.trackByFn = (_, item) => item.id;
    }
}
BbNotificationsList.decorators = [
    { type: Component, args: [{
                selector: 'bb-notifications-list',
                template: "<!--\r\n    The notifications list.\r\n\r\n    The list provides the animation effect for the\r\n    incoming notifications.\r\n-->\r\n<div *ngIf=\"notifications$ | async as notifications\"\r\n     [@notificationListAnimation]=\"notifications.length\"\r\n     class=\"notifications-list-wrapper\">\r\n    <!--\r\n        The loop for the notifications.\r\n\r\n        All notifications will be displayed here. They\r\n        are wrapped within a wrapper which separates them.\r\n    -->\r\n    <div *ngFor=\"let notification of notifications; trackBy: trackByFn\"\r\n         class=\"notifications-item-wrapper\">\r\n        <bb-notifications-item [notification]=\"notification\"\r\n                               [dismissButtonText]=\"dismissText\">\r\n        </bb-notifications-item>\r\n    </div>\r\n</div>",
                animations: [notificationAnimation],
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'class': 'bb-notifications-list',
                    'role': 'list'
                },
                styles: [".bb-notifications-list{top:0;right:0;bottom:0;width:100%;z-index:500;padding:10px;display:block;position:fixed;max-width:400px;pointer-events:none}.notifications-list-wrapper{width:100%;display:block;position:relative}.notifications-item-wrapper{padding:0;margin:0 0 10px;pointer-events:all}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbNotificationsItem {
    /**
     * @param {?} _zone
     * @param {?} _platform
     * @param {?} _changeDetection
     */
    constructor(_zone, _platform, _changeDetection) {
        this._zone = _zone;
        this._platform = _platform;
        this._changeDetection = _changeDetection;
        // Data.
        this._progress = 0;
        this._count = 0;
        // Data.
        this._radius = 19;
        this._circumference = this._radius * 2 * Math.PI;
        this.callActionAndDestroy = (notification, action) => {
            // Perform the callback (if it exists).
            action && action.callback && action.callback();
            // Call the destroy method (if it exists).
            notification && notification.destroy && notification.destroy();
        };
        this.instance = () => {
            // Calculate the difference.
            this._difference = (new Date().getTime() - this._startTime) - (this._count * this._speed);
            // Add up the count.
            if (this._count++ === this._steps) {
                this.notification.destroy();
            }
            // Add the steps to the progress.
            this._progress += 100 / this._steps;
            // Set a new timer.
            this._timer = this.setTimeout(this.instance, this._speed - this._difference);
            // Run a new change detection cycle.
            this._zone.run(() => this._changeDetection.detectChanges());
        };
        this.setTimeout = (method, timeout) => {
            // Check if the window and method exist.
            if (!window || !window.setTimeout) {
                return null;
            }
            return window.setTimeout(method, timeout);
        };
    }
    /**
     * @return {?}
     */
    get getClass() {
        return `bb-notifications-item ${this.notification.type}`;
    }
    /**
     * @return {?}
     */
    get progressStrokeArray() {
        /** @type {?} */
        const value = Math.floor(this._circumference);
        return `${value}, ${value}`;
    }
    /**
     * @return {?}
     */
    get progressStrokeOffset() {
        return Math.floor(this._circumference - this._progress / 100 * this._circumference);
    }
    /**
     * @return {?}
     */
    get isContentString() {
        return typeof this.notification.content === 'string';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // Check if the notification timeout is not 0 and the platform is a browser.
        if (this.notification.timeout <= 0 || !this._platform.isBrowser) {
            this.notification.dismiss = true;
            return;
        }
        // Start the timeout.
        this.startTimeout();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // Clear the timeout if it was set.
        this._timer && window && window.clearTimeout && window.clearTimeout(this._timer);
    }
    /**
     * @private
     * @return {?}
     */
    startTimeout() {
        // Calculate the steps of the timeout.
        this._steps = this.notification.timeout / 10;
        // Calculate the speed of the timeout.
        this._speed = this.notification.timeout / this._steps;
        // Get the start time.
        this._startTime = new Date().getTime();
        // Set a new timer outside of Angular.
        this._zone.runOutsideAngular(() => this._timer = this.setTimeout(this.instance, this._speed));
    }
}
BbNotificationsItem.decorators = [
    { type: Component, args: [{
                selector: 'bb-notifications-item',
                template: "<div class=\"notification-content-wrapper\">\r\n    <!--\r\n        The icon for the notification.\r\n\r\n        The icon is reflected by the type of the\r\n        notification. Same goes for the color and\r\n        background-color.\r\n    -->\r\n    <div *ngIf=\"notification?.icon as icon\"\r\n         [style.color]=\"notification?.color\"\r\n         [style.background-color]=\"notification?.backgroundColor\"\r\n         class=\"notification-icon-wrapper\">\r\n        <i class=\"material-icons\">\r\n            {{ icon }}\r\n        </i>\r\n\r\n        <!--\r\n            The circular progress for the notification.\r\n\r\n            The progress is only visible when a timeout is\r\n            set. The progress adapts to the time remaining\r\n            for the notification.\r\n        -->\r\n        <svg *ngIf=\"notification?.timeout > 0\"\r\n             class=\"notification-progress-ring\"\r\n             viewBox=\"0 0 40 40\"\r\n             role=\"progressbar\">\r\n            <circle #progress\r\n                    [attr.stroke-dasharray]=\"progressStrokeArray\"\r\n                    [attr.stroke-dashoffset]=\"progressStrokeOffset\"\r\n                    [style.stroke]=\"notification?.color\"\r\n                    class=\"notification-progress-circle\"\r\n                    stroke-width=\"2\"\r\n                    fill=\"transparent\"\r\n                    r=\"19\"\r\n                    cx=\"20\"\r\n                    cy=\"20\">\r\n            </circle>\r\n        </svg>\r\n    </div>\r\n\r\n    <!--\r\n        The content for the notification.\r\n\r\n        This displays a string or a template based\r\n        on the given parameter by the user.\r\n    -->\r\n    <div class=\"notification-content\">\r\n        <ng-container *ngIf=\"isContentString; else templateContent\">\r\n            {{ notification?.content }}\r\n        </ng-container>\r\n    </div>\r\n</div>\r\n\r\n<!--\r\n    The actions of the notification.\r\n\r\n    All actions are displayed here and are\r\n    based on the actions array the user provided.\r\n-->\r\n<div *ngIf=\"notification?.actions?.length > 0 || notification?.dismiss\"\r\n     class=\"notification-actions\">\r\n    <button *ngFor=\"let action of notification?.actions\"\r\n            (click)=\"callActionAndDestroy(notification, action)\"\r\n            type=\"button\"\r\n            class=\"notification-actions-button\">\r\n        {{ action?.title }}\r\n    </button>\r\n    <button *ngIf=\"notification?.dismiss\"\r\n            (click)=\"notification?.destroy()\"\r\n            type=\"button\"\r\n            class=\"notification-actions-button\">\r\n        {{ notification?.dismissText || dismissButtonText }}\r\n    </button>\r\n</div>\r\n\r\n<!--\r\n    The outlet for the notification content template ref.\r\n-->\r\n<ng-template #templateContent>\r\n    <ng-container *ngTemplateOutlet=\"notification?.content\"></ng-container>\r\n</ng-template>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                preserveWhitespaces: false,
                host: {
                    'role': 'alert'
                },
                styles: [".bb-notifications-item{display:-ms-flexbox;display:flex;border-radius:4px;-ms-flex-direction:column;flex-direction:column;background-color:#fff;border:1px solid #d6dbe0}.bb-notifications-item.success .notification-icon-wrapper{color:#36d068;background-color:#ebfaf0}.bb-notifications-item.success .notification-progress-circle{stroke:#36d068}.bb-notifications-item.error .notification-icon-wrapper{color:#f55656;background-color:#feeeee}.bb-notifications-item.error .notification-progress-circle{stroke:#f55656}.bb-notifications-item.warning .notification-icon-wrapper{color:#ffbc0b;background-color:#fff8e7}.bb-notifications-item.warning .notification-progress-circle{stroke:#ffbc0b}.bb-notifications-item.info .notification-icon-wrapper{color:#22a5f7;background-color:#e9f6fe}.bb-notifications-item.info .notification-progress-circle{stroke:#22a5f7}.bb-notifications-item.custom .notification-icon-wrapper{color:#657385;background-color:#f3f5f6}.bb-notifications-item.custom .notification-progress-circle{stroke:#657385}.notification-content-wrapper{padding:20px;display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center}.notification-icon-wrapper{width:40px;height:40px;display:-ms-flexbox;display:flex;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;position:relative;border-radius:50%;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center;color:#657385;background-color:#f3f5f6}.notification-content{-ms-flex:1;flex:1;font-size:14px;line-height:1.5;font-weight:500;margin-left:20px;color:rgba(0,0,0,.85)}.notification-content i{font-style:italic}.notification-actions-button,.notification-content{font-family:inherit}.notification-actions{display:-ms-flexbox;display:flex;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;border-top:1px solid #f3f5f6}.notification-actions>.notification-actions-button:not(:last-child){border-right:1px solid #f3f5f6}.notification-actions-button{-ms-flex:1;flex:1;border:none;color:#22a5f7;cursor:pointer;font-size:14px;font-weight:500;padding:12px 20px;text-align:center;background-color:transparent;transition:background-color 150ms cubic-bezier(0,0,.2,1)}.notification-actions-button:hover{background-color:rgba(34,165,247,.04)}.notification-actions-button:active{text-decoration:underline;background-color:rgba(34,165,247,.08)}.notification-progress-ring{top:0;left:0;right:0;bottom:0;width:100%;height:100%;position:absolute}.notification-progress-circle{-webkit-transform:rotate(-90deg);-ms-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:50% 50%;-ms-transform-origin:50% 50%;transform-origin:50% 50%;stroke:#657385}"]
            }] }
];
/** @nocollapse */
BbNotificationsItem.ctorParameters = () => [
    { type: NgZone },
    { type: Platform },
    { type: ChangeDetectorRef }
];
BbNotificationsItem.propDecorators = {
    notification: [{ type: Input }],
    dismissButtonText: [{ type: Input }],
    progressElementRef: [{ type: ViewChild, args: ['progress',] }],
    getClass: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbNotificationsModule {
    /**
     * @param {?} parentModule
     */
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('BbNotificationsModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?=} config
     * @return {?}
     */
    static forRoot(config) {
        return {
            ngModule: BbNotificationsModule,
            providers: [
                { provide: BbNotificationsConfig, useValue: config }
            ]
        };
    }
}
BbNotificationsModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [BbNotificationsList, BbNotificationsItem],
                entryComponents: [BbNotificationsList]
            },] }
];
/** @nocollapse */
BbNotificationsModule.ctorParameters = () => [
    { type: BbNotificationsModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbNotifications {
    /**
     * @param {?} _platform
     * @param {?} _injector
     * @param {?} _applicationRef
     * @param {?} _config
     * @param {?} _componentFactoryResolver
     */
    constructor(_platform, _injector, _applicationRef, _config, _componentFactoryResolver) {
        this._platform = _platform;
        this._injector = _injector;
        this._applicationRef = _applicationRef;
        this._config = _config;
        this._componentFactoryResolver = _componentFactoryResolver;
        // The default presets for the notification types.
        this._icons = {
            [BbNotificationType.Success]: 'check',
            [BbNotificationType.Error]: 'notification_important',
            [BbNotificationType.Warning]: 'notification_important',
            [BbNotificationType.Info]: 'star',
            [BbNotificationType.Custom]: 'adb'
        };
        // The data containing the notifications.
        this._notifications$ = new BehaviorSubject([]);
        this.getProperty = (property, defaultValue) => {
            return typeof property === 'undefined'
                ? defaultValue
                : property;
        };
        // Get the config.
        /** @type {?} */
        const config = this._config || {};
        // Set the config.
        this._defaultMode = this.getProperty(config.mode, 'prepend');
        this._defaultTimeout = this.getProperty(config.timeout, 8000);
        this._defaultDismiss = this.getProperty(config.dismiss, true);
        this._defaultDismissText = this.getProperty(config.dismissText, 'Dismiss');
        // Create the element that holds all notifications.
        this.createElement();
    }
    /**
     * @param {?} content
     * @param {?=} actions
     * @param {?=} timeout
     * @return {?}
     */
    success(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: BbNotificationType.Success });
    }
    /**
     * @param {?} content
     * @param {?=} actions
     * @param {?=} timeout
     * @return {?}
     */
    error(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: BbNotificationType.Error });
    }
    /**
     * @param {?} content
     * @param {?=} actions
     * @param {?=} timeout
     * @return {?}
     */
    warn(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: BbNotificationType.Warning });
    }
    /**
     * @param {?} content
     * @param {?=} actions
     * @param {?=} timeout
     * @return {?}
     */
    info(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: BbNotificationType.Info });
    }
    /**
     * @param {?} notification
     * @return {?}
     */
    create(notification) {
        // Compose a new notification item.
        /** @type {?} */
        const item = this.compose(notification);
        // Add the destroy function to the notification.
        item.destroy = () => this.pull(item);
        // Add the notification to the list
        // and return the item.
        return this.push(item);
    }
    /**
     * @private
     * @param {?} notification
     * @return {?}
     */
    push(notification) {
        // Get the current list.
        /** @type {?} */
        const oldList = this._notifications$.getValue();
        // Check which mode is activated.
        /** @type {?} */
        let newList = [...oldList];
        switch (this._defaultMode) {
            case 'append':
                newList = [...oldList, notification];
                break;
            case 'prepend':
            default:
                newList = [notification, ...oldList];
        }
        // Push the new notifications.
        this._notifications$.next(newList);
        // Return the notification for further use.
        return notification;
    }
    /**
     * @private
     * @param {?} notification
     * @return {?}
     */
    pull(notification) {
        // Get the current list.
        /** @type {?} */
        const newList = this._notifications$
            .getValue()
            .filter(item => item.id !== notification.id);
        // Push a new list.
        this._notifications$.next(newList);
    }
    /**
     * @private
     * @param {?} notification
     * @return {?}
     */
    compose(notification) {
        // Attach a random id to the notification.
        notification.id = Math.random().toString(36).substr(2, 10);
        // Set all properties.
        notification.type = this.getProperty(notification.type, BbNotificationType.Custom);
        notification.content = this.getProperty(notification.content, null);
        notification.timeout = this.getProperty(notification.timeout, this._defaultTimeout);
        notification.dismiss = this.getProperty(notification.dismiss, this._defaultDismiss);
        notification.dismissText = this.getProperty(notification.dismissText, this._defaultDismissText);
        /** @type {?} */
        const defaultIcon = this._icons[notification.type] || this._icons[BbNotificationType.Custom];
        notification.icon = this.getProperty(notification.icon, defaultIcon);
        // Return the composed notification.
        return notification;
    }
    /**
     * @private
     * @return {?}
     */
    createElement() {
        // Create the notification list and
        // get a reference to the component.
        this._ref = this._componentFactoryResolver
            .resolveComponentFactory(BbNotificationsList)
            .create(this._injector);
        // Save a reference to the notifications on
        // the component.
        this._ref.instance.notifications$ = this._notifications$.pipe(share());
        this._ref.instance.dismissText = this._defaultDismissText;
        // Attach the component's view to the application
        // so that the change detection will run properly.
        this._applicationRef.attachView(this._ref.hostView);
        // If the platform is not a browser return.
        if (!this._platform.isBrowser) {
            return;
        }
        try {
            // Append the element to the DOM.
            document.body.appendChild(this._ref.location.nativeElement);
        }
        catch (_a) {
            // Don't do anything, because it must've failed.
        }
    }
}
BbNotifications.decorators = [
    { type: Injectable, args: [{
                providedIn: BbNotificationsModule
            },] }
];
/** @nocollapse */
BbNotifications.ctorParameters = () => [
    { type: Platform },
    { type: Injector },
    { type: ApplicationRef },
    { type: BbNotificationsConfig, decorators: [{ type: Optional }] },
    { type: ComponentFactoryResolver }
];
/** @nocollapse */ BbNotifications.ngInjectableDef = defineInjectable({ factory: function BbNotifications_Factory() { return new BbNotifications(inject(Platform), inject(INJECTOR), inject(ApplicationRef), inject(BbNotificationsConfig, 8), inject(ComponentFactoryResolver)); }, token: BbNotifications, providedIn: BbNotificationsModule });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { Platform, Language, BbDashboard, BbDashboardHeader, BbDashboardSidebar, BbDashboardSidebarGroup, BbDashboardSidebarItem, BbDashboardModule, BbNotificationType, BbNotificationsConfig, BbNotifications, BbNotificationsModule, BbNotificationsItem as ɵc, BbNotificationsList as ɵa, notificationAnimation as ɵb };

//# sourceMappingURL=bravobit-bb-foundation.js.map